@@ -5,7 +5,7 @@ use warnings;
 
 require Exporter;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 our @ISA = qw(Exporter);
 
@@ -27,11 +27,12 @@ iscntrl isdigit isfinite isgraph isinf islower isnan isnormal isprint ispunct
 isspace isupper isxdigit j0 j1 jn jrand48 killpg l64a ldexp ldiv lgamma link
 linkat log1p log2 logb lrand48 lround lstat mkdir mkdirat mkdtemp mkfifo
 mkfifoat mknod mknodat mkstemp mrand48 nanosleep nearbyint nextafter nrand48
-openat open pread ptsname pwrite pwritev random read readlink readlinkat
-remainder remove rename renameat round scalbn seed48 setegid seteuid setgid
-setitimer setpriority setregid setreuid setuid setutxent sighold sigignore
-signbit sigpause sigrelse sinh srand48 srandom stat symlink symlinkat sync tan
-tanh tgamma truncate trunc unlinkat unlink utimensat write writev y0 y1 yn
+openat open pread preadv ptsname pwrite pwritev random read readlink
+readlinkat readv remainder remove rename renameat round scalbn seed48 setegid
+seteuid setgid setitimer setpriority setregid setreuid setuid setutxent
+sighold sigignore signbit sigpause sigrelse sinh srand48 srandom stat strptime
+symlink symlinkat sync tan tanh tgamma truncate trunc unlinkat unlink
+utimensat write writev y0 y1 yn
 
 AT_EACCESS AT_EMPTY_PATH AT_FDCWD AT_NO_AUTOMOUNT AT_REMOVEDIR
 AT_SYMLINK_FOLLOW AT_SYMLINK_NOFOLLOW BOOT_TIME CLOCK_BOOTTIME CLOCK_HIGHRES
@@ -53,13 +54,11 @@ our %EXPORT_TAGS = (
   'at'    => [grep(/^AT_/, @EXPORT_OK), grep(/at$/ && !/^l?stat$/, @EXPORT_OK)],
   'id'    => [grep /^[gs]et.+id$/, @EXPORT_OK],
   'clock' => [grep /^clock/i, @EXPORT_OK],
-  'rw'    => [qw(read write writev)],
-  'prw'   => [qw(pread pwrite pwritev)],
+  'rw'    => [qw(read write readv writev)],
+  'prw'   => [qw(pread preadv pwrite pwritev)],
   'is'    => [grep /^is/, @EXPORT_OK],
 );
 
-sub DESTROY { }
-
 our $AUTOLOAD;
 sub AUTOLOAD {
   my $constname;
